@@ -330,7 +330,8 @@ def data_aug(aug_file, data_dir):
     imgfiles_all = os.listdir(IMG_DIR)
     imgfiles = []
     for item in imgfiles_all:
-        if item.split(".")[0] in xml_trainval_ori:
+        # if item.split(".")[0] in xml_trainval_ori:
+        if os.path.splitext(item)[0] in xml_trainval_ori:
             imgfiles.append(item)
 
     if not config_dict["basic"]["thread_num"]:
@@ -362,7 +363,7 @@ if __name__ == "__main__":
     # aug(args)
 
     aug_config = "./aug.yml"
-    data_folder = "../../test/voc_eva_clothes_helmet"
+    data_folder = "C:/Users/xgy/Desktop/1111/VOC"
     data_aug(aug_config, data_folder)
 
     # IMG_DIR = data_folder + os.sep + "JPEGImages"
