@@ -5,6 +5,7 @@ Created on 2021-8-27
 @author: zhys513(254851907@qq.com)
 '''
 import os
+import math
 from xml.etree.ElementTree import ElementTree, Element
 
 
@@ -124,7 +125,7 @@ def gen_voc_xml(boxes: list, file_path, img_w, img_h, out_file):
     annotation.append(segmented)
 
     for index, box in enumerate(boxes):
-        object_item = gen_object(box["category"], box["xmin"], box["ymin"], box["xmax"], box["ymax"],)
+        object_item = gen_object(box["category"], math.ceil(box["xmin"]), math.ceil(box["ymin"]), math.floor(box["xmax"]), math.floor(box["ymax"]))
         annotation.append(object_item)
 
     __indent(annotation)
